@@ -5,12 +5,12 @@ import json
 from nanoid import generate
 from redis.client import StrictRedis
 from redis.connection import ConnectionPool
-from core.actors import Args, Actor, ComputeActor, SinkActor, SourceActor
-from core.utils import base64_utils, dict_utils
-from core.constants import actor_constant, config
-from core.streams import RedisConsumer, RedisProducer
-from core.utils.actor_utils import FlowStateUtils
-from core.payload import Message
+from cloudam_stream.core.actors import Args, Actor, ComputeActor, SinkActor, SourceActor
+from cloudam_stream.core.utils import base64_utils, dict_utils
+from cloudam_stream.core.constants import actor_constant, config
+from cloudam_stream.core.streams import RedisConsumer, RedisProducer
+from cloudam_stream.core.utils.actor_utils import FlowStateUtils
+from cloudam_stream.core.payload import Message
 import pickle
 
 upstream_actors_states = {}
