@@ -1,5 +1,5 @@
-from core.ports.port import Port
-from core.payload import Record
+from cloudam_stream.core.ports.port import Port
+from cloudam_stream.core.payload import Record
 import json
 
 
