@@ -1,5 +1,5 @@
-from core.constants import actor_constant
-from core.utils import redis_utils
+from cloudam_stream.core.constants import actor_constant
+from cloudam_stream.core.utils import redis_utils
 
 
 class FlowStateUtils(object):
