@@ -1,7 +1,7 @@
-from core.actors import ParallelComputeActor
-from core.ports.outputports import TextOutputPort
+from cloudam_stream.core.actors import ParallelComputeActor
+from cloudam_stream.core.ports.outputports import TextOutputPort
 
-from core.ports.inputports import TextInputPort
+from cloudam_stream.core.ports.inputports import TextInputPort
 
 
 class MyParallelComputeActor(ParallelComputeActor):
