@@ -1,7 +1,7 @@
-from core.actors import SinkActor
-from core.constants import config
+from cloudam_stream.core.actors import SinkActor
+from cloudam_stream.core.constants import config
 
-from core.ports.inputports import TextInputPort
+from cloudam_stream.core.ports.inputports import TextInputPort
 
 
 class MySinkActor(SinkActor):
